@@ -6,20 +6,14 @@ Created on Sun Sep 27 09:52:50, 2015
 
 @author: gtucker, amended dejh
 """
+import numpy as np  # for use of np.round
 import pytest
+from numpy import pi, sin
+from numpy.testing import assert_array_equal
 from pytest import approx
 
-import landlab
-from landlab import RasterModelGrid
-from landlab.components import (FlowAccumulator,
-                                DepressionFinderAndRouter,
-                                FlowAccumulator)
-
-from numpy import sin, pi
-import numpy as np  # for use of np.round
-from numpy.testing import assert_array_equal
-from landlab import BAD_INDEX_VALUE as XX
-
+from landlab import BAD_INDEX_VALUE as XX, RasterModelGrid
+from landlab.components import DepressionFinderAndRouter, FlowAccumulator
 
 NUM_GRID_ROWS = 8
 NUM_GRID_COLS = 8
@@ -29,9 +23,9 @@ PERIOD_Y = 4.
 
 def test_route_to_multiple_error_raised():
     mg = RasterModelGrid((10, 10))
-    z = mg.add_zeros('node', 'topographic__elevation')
+    z = mg.add_zeros("node", "topographic__elevation")
     z += mg.x_of_node + mg.y_of_node
-    fa = FlowAccumulator(mg, flow_director='MFD')
+    fa = FlowAccumulator(mg, flow_director="MFD")
     fa.run_one_step()
 
     with pytest.raises(NotImplementedError):
@@ -68,7 +62,7 @@ def check_fields1(grid):
         grid.at_node["depression__depth"]
         grid.at_node["depression__outlet_node"]
         grid.at_node["is_pit"]
-    except:
+    except KeyError:
         print("Test failure in check_fields")
         raise
 
@@ -511,7 +505,7 @@ def check_fields2(grid):
         grid.at_node["depression__depth"]
         grid.at_node["depression__outlet_node"]
         grid.at_node["is_pit"]
-    except:
+    except KeyError:
         print("Test failure in check_fields")
         raise
 
@@ -1282,7 +1276,7 @@ def test_edge_draining():
 
     mg.add_field("node", "topographic__elevation", z, units="-")
 
-    fr = FlowAccumulator(mg, flow_director='D8')
+    fr = FlowAccumulator(mg, flow_director="D8")
     lf = DepressionFinderAndRouter(mg)
 
     fr.run_one_step()
@@ -1303,9 +1297,9 @@ def test_degenerate_drainage():
     z_init[22] = 0.  # the common spill pt for both lakes
     z_init[21] = 0.1  # an adverse bump in the spillway
     z_init[20] = -0.2  # the spillway
-    z = mg.add_field("node", "topographic__elevation", z_init)
+    mg.add_field("node", "topographic__elevation", z_init)
 
-    fr = FlowAccumulator(mg, flow_director='D8')
+    fr = FlowAccumulator(mg, flow_director="D8")
     lf = DepressionFinderAndRouter(mg)
     fr.run_one_step()
     lf.map_depressions()
@@ -1370,8 +1364,6 @@ def test_degenerate_drainage():
         ]
     )
 
-    thelake = np.concatenate((lake_pits, [22])).sort()
-
     assert mg.at_node["drainage_area"] == approx(correct_A)
 
 
@@ -1390,7 +1382,7 @@ def test_three_pits():
     z[43] = 1.
     z[37] = 4.
     z[74:76] = 1.
-    fr = FlowAccumulator(mg, flow_director='D8')
+    fr = FlowAccumulator(mg, flow_director="D8")
     lf = DepressionFinderAndRouter(mg)
     fr.run_one_step()
     lf.map_depressions()
@@ -1547,7 +1539,7 @@ def test_composite_pits():
     # make an outlet
     z[71] = 0.9
 
-    fr = FlowAccumulator(mg, flow_director='D8')
+    fr = FlowAccumulator(mg, flow_director="D8")
     lf = DepressionFinderAndRouter(mg)
     fr.run_one_step()
     lf.map_depressions()
