@@ -2,4 +2,4 @@ from .voronoi import VoronoiGraph
 from .dual_voronoi import DualVoronoiGraph
 
 
-__all__ = ['VoronoiGraph', 'DualVoronoiGraph']
+__all__ = ["VoronoiGraph", "DualVoronoiGraph"]
